@@ -11,7 +11,7 @@ class Freebox(object):
 
 class FreeboxResource(resources.Resource):
     class Meta:
-        resource_name = 'Freebox'
+        resource_name = 'freebox'
         allowed_methods = ()
         authorization = authorization.Authorization()
         object_class = Freebox
